// the us log module
// date: 2022-04-11
// by nfs.chongqing.develope.department
// this is a log module in UI SDK ，provide log functions like syslog for system developers or application developers


#ifndef _UI_LOG_H
#define _UI_LOG_H 1




/* 文件路径长度 */
#define MAX_PATH 4096

/* 文件名称长度 */
#define MAX_NAME 256

/* 消息最大长度 */
#define MAX_MSG 4096

/* 单个日志文件的最大大小，单位为bytes */
#define MAX_FILE_SIZE 2 * 1024 * 1024 * 1024  /* 2GB */

/* 限制每条日志信息大小，单位为bytes */
#define MAX_LOG_DATA_SIZE 128 * 1024 * 1024  /* 128MB */


/* 各种消息类型长度 */
#define GUID_LEN 32
#define MSG_TYPE_LEN sizeof(int)
#define LOG_LEVEL_LEN sizeof(int)
#define FILE_SIZE_LEN sizeof(unsigned long long)
#define FILE_COUNTER_LEN sizeof(unsigned int)


/* 单类日志最多保留日志文件个数，范围为1-100 */
#define MIX_FILE_COUNT 1
#define MAX_FILE_COUNT 100


/* 存放日志文件父目录 */
#define LOG_DIR_BASE "/var/log/"

/* 日志文件名称前缀
 * 预留前缀，如果需要添加前缀，则使用此定义。如 us_messages、us_warning 等
 */
#define LOG_FILE_NAME_PRE "us_"


/* 
 * 日志级别
 * 日志等级越低情况越严重 
 */
#define	LOG_EMERG	0	/* 系统不可用 */
#define	LOG_ALERT	1	/* 必须马上采取行动的事件 */
#define	LOG_CRIT	2	/* 关键的事件 */
#define	LOG_ERR		3	/* 错误事件 */
#define	LOG_WARNING	4	/* 警告事件 */
#define	LOG_NOTICE	5	/* 普通但重要的事件 */
#define	LOG_INFO	6	/* 有用的信息 */
#define	LOG_DEBUG	7	/* 调试信息 */


/* 定义描述日志配置信息的数据结构us_log_conf_t */
typedef struct _us_log_conf{
    char log_dir[MAX_NAME];         /* 存放日志文件子目录，父目录固定为 /var/log/ ，所有日志文件将写入到该目录；如果为”syslog”则使用标准的syslog写日志，并且其他配置项无效 */
    int  log_level;                 /* 当前输出日志等级(emerg,alert,crit,err,warning,notice,info,debug)，例如日志等级设置为info,则小于info等级不输出，仅输出info,debug级别的日志 */
    unsigned long long filesize;    /* 单个日志文件的最大大小，单位为bytes，最大为2GB */
    unsigned int file_counter;          /* 单类日志最多保留日志文件个数，范围为1-100 */
}us_log_conf_t; 


/* 接口调用返回的错误码 */
#define CODE_SUCCESS                        0       /* 执行成功 */
#define CODE_FAILD                          1       /* 执行失败 */
#define CODE_ERROR                          2       /* 执行遇到错误 */
#define CODE_NOT_INITIALIZE                 3       /* 未调用 us_init_log 接口初始化日志句柄 */
#define CODE_LEVEL_INFO_ERROR               4       /* 日志级别设置错误 */
#define CODE_CREATE_DIRECTORY_FAILD         5       /* 创建日志文件夹失败 */
#define CODE_OPEN_OR_CREATE_FILE_FAILD      6       /* 打开/创建日志文件失败 */
#define CODE_WRITE_FILE_FAILD               7       /* 写入日志文件失败 */
#define CODE_DELETE_FILE_FAILD              8       /* 删除日志文件失败 */
#define CODE_RENAME_FILE_FAILD              9       /* 修改日志文件名称失败 */
#define CODE_DELETE_FILE_DATA_FAILD         10       /* 删除日志文件内容失败 */
#define CODE_LEVEL_NOT_IN_PRINT             11       /* 日志等级小于指定等级的日志不输出 */
#define CODE_LEVEL_ERROR                    12       /* 设置 level 参数错误 */
#define CODE_USE_LEVEL_FILE_FLAG_ERROR      13       /* 设置 use_level_file_flag 参数错误 */
#define CODE_USER_LOG_CONFIG_ERROR          14       /* 设置 us_log_conf_t 参数错误 */
#define CODE_CONNECT_FAILD                  15       /* 连接守护进程失败 */



/* 设置日志配置，该接口的调用是非线程安全
 *
 * 参数conf： 定义描述日志配置信息的数据结构us_log_conf_t
 */
int _us_init_log(const us_log_conf_t *conf);


/* 输出等级日志，该接口的调用是非线程安全
 *
 * 参数level：日志等级，参考us_set_level罗列的日志等级说明
 * 参数msg：日志内容
 *
 * 返回值：
        0：成功
        其他：失败，错误码
 */
int _us_log(int level, const char *msg);

void _us_close();


#endif  /* ui_log.h */
